// to be placed in the posessing classes ..
#define NFAIL 		0
#define DFAIL 		0
#define NOK 		1
#define WOK 		1
#define DOK 		1
#define WCONN 		10
#define WDISC 		11
#define WSHORT 		12
#define DCONN 		13
#define DDISC 		14
#define DFAILMAXI 	15
#define DFAILMAXO 	16

// messages
#define NEWWIRE		"wire creation with point p not in wire???"
#define NOACTIVE	"no active node!"
#define NOACTIVECONN	"connectInput: no active node or node not end-node!"

// default font definition
#define FONTTYPE	"adobe-courier"
#define FONTSIZE	8
#define FONTAPPEARANCE	QFont::Normal

#ifndef __KLOGIC_GLOBAL__
#define __KLOGIC_GLOBAL__
#include <qstring.h>
#include <klocale.h>

namespace Global
{
	class Klogic
	{
	public:
		static const QString Name;
		static const QString emptyFileName;
	};

	class Screen
	{
	public:
		static const int SCREEN_SIZE_X = 800;
		static const int SCREEN_SIZE_Y = 600;

		static int VIRT_SCREEN_SIZE_X;
		static int VIRT_SCREEN_SIZE_Y;
	};

	class CurrentCircuit
	{
	public:
		static QString filename;
		static QString version;
		static QString creation;
		static QString author;
		static QString title;
		static QString comment;
	};

};

class uniqueID
{
public:
	static void reset() { id = 0; };
	static int getID() { return ++id; };
private:
	static int id;
};

#endif
